@@ -1,6 +1,6 @@
 /**
   Copyright 1993 Bill Triggs <Bill.Triggs@inrialpes.fr>
-  Copyright 1995-2017 Bruno Haible <bruno@clisp.org>
+  Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 **/
 /*----------------------------------------------------------------------
   !!! THIS ROUTINE MUST BE COMPILED gcc -O !!!
@@ -67,14 +67,14 @@
 /* This declaration tells gcc not to modify %r28. */
 register __avword*	sret	__asm__("%r28");  /* structure return pointer */
 
-register __avword arg1 __asm__("r26");
-register __avword arg2 __asm__("r25");
-register __avword arg3 __asm__("r24");
-register __avword arg4 __asm__("r23");
-register __avword arg5 __asm__("r22");
-register __avword arg6 __asm__("r21");
-register __avword arg7 __asm__("r20");
-register __avword arg8 __asm__("r19");
+register __avrword arg1 __asm__("r26");
+register __avrword arg2 __asm__("r25");
+register __avrword arg3 __asm__("r24");
+register __avrword arg4 __asm__("r23");
+register __avrword arg5 __asm__("r22");
+register __avrword arg6 __asm__("r21");
+register __avrword arg7 __asm__("r20");
+register __avrword arg8 __asm__("r19");
 
 /*register float farg1 __asm__("fr4R");*/
 /*register float farg2 __asm__("fr5R");*/
@@ -98,15 +98,15 @@ int
 avcall_call(av_alist* list)
 {
   register __avword*	sp	__asm__("%r30");  /* C names for registers */
-/*register __avword	iret1	__asm__("%r28"); */
-  register __avword	iret2	__asm__("%r29");
+/*register __avrword	iret1	__asm__("%r28"); */
+  register __avrword	iret2	__asm__("%r29");
 
   __av_alist* l = &AV_LIST_INNER(list);
 
   __avword* argframe = __builtin_alloca(__AV_ALIST_WORDS * sizeof(__avword)); /* make room for argument list */
   __avword* memargptr;
   int arglen = l->aptr - l->args;
-  __avword iret;
+  __avrword iret;
 
   {
     int i;
@@ -129,49 +129,49 @@ avcall_call(av_alist* list)
       if (l->darg_mask & (1 << 1))
         darg2 = ((double*)&l->args[2])[-1];
       else if (l->farg_mask & (1 << 1))
-        __asm__ __volatile__ ("fldw %0,%%fr5R" : : "m" (((float*)&l->args[2])[-1])); /* farg2 = ((float*)&l->args[2])[-1];; */
+        __asm__ __volatile__ ("fldw %0,%%fr5R" : : "m" (((float*)&l->args[2])[-1])); /* farg2 = ((float*)&l->args[2])[-1]; */
       else
         arg2 = l->args[1];
       if (arglen >= 3) {
         if (l->darg_mask & (1 << 2))
           darg3 = ((double*)&l->args[3])[-1];
         else if (l->farg_mask & (1 << 2))
-          __asm__ __volatile__ ("fldw %0,%%fr6R" : : "m" (((float*)&l->args[3])[-1])); /* farg3 = ((float*)&l->args[3])[-1];; */
+          __asm__ __volatile__ ("fldw %0,%%fr6R" : : "m" (((float*)&l->args[3])[-1])); /* farg3 = ((float*)&l->args[3])[-1]; */
         else
           arg3 = l->args[2];
         if (arglen >= 4) {
           if (l->darg_mask & (1 << 3))
             darg4 = ((double*)&l->args[4])[-1];
           else if (l->farg_mask & (1 << 3))
-            __asm__ __volatile__ ("fldw %0,%%fr7R" : : "m" (((float*)&l->args[4])[-1])); /* farg4 = ((float*)&l->args[4])[-1];; */
+            __asm__ __volatile__ ("fldw %0,%%fr7R" : : "m" (((float*)&l->args[4])[-1])); /* farg4 = ((float*)&l->args[4])[-1]; */
           else
             arg4 = l->args[3];
           if (arglen >= 5) {
             if (l->darg_mask & (1 << 4))
               darg5 = ((double*)&l->args[5])[-1];
             else if (l->farg_mask & (1 << 4))
-              __asm__ __volatile__ ("fldw %0,%%fr8R" : : "m" (((float*)&l->args[5])[-1])); /* farg5 = ((float*)&l->args[5])[-1];; */
+              __asm__ __volatile__ ("fldw %0,%%fr8R" : : "m" (((float*)&l->args[5])[-1])); /* farg5 = ((float*)&l->args[5])[-1]; */
             else
               arg5 = l->args[4];
             if (arglen >= 6) {
               if (l->darg_mask & (1 << 5))
                 darg6 = ((double*)&l->args[6])[-1];
               else if (l->farg_mask & (1 << 5))
-                __asm__ __volatile__ ("fldw %0,%%fr9R" : : "m" (((float*)&l->args[6])[-1])); /* farg6 = ((float*)&l->args[6])[-1];; */
+                __asm__ __volatile__ ("fldw %0,%%fr9R" : : "m" (((float*)&l->args[6])[-1])); /* farg6 = ((float*)&l->args[6])[-1]; */
               else
                 arg6 = l->args[5];
               if (arglen >= 7) {
                 if (l->darg_mask & (1 << 6))
                   darg7 = ((double*)&l->args[7])[-1];
                 else if (l->farg_mask & (1 << 6))
-                  __asm__ __volatile__ ("fldw %0,%%fr10R" : : "m" (((float*)&l->args[7])[-1])); /* farg7 = ((float*)&l->args[7])[-1];; */
+                  __asm__ __volatile__ ("fldw %0,%%fr10R" : : "m" (((float*)&l->args[7])[-1])); /* farg7 = ((float*)&l->args[7])[-1]; */
                 else
                   arg7 = l->args[6];
                 if (arglen >= 8) {
                   if (l->darg_mask & (1 << 7))
                     darg8 = ((double*)&l->args[8])[-1];
                   else if (l->farg_mask & (1 << 7))
-                    __asm__ __volatile__ ("fldw %0,%%fr11R" : : "m" (((float*)&l->args[8])[-1])); /* farg8 = ((float*)&l->args[8])[-1];; */
+                    __asm__ __volatile__ ("fldw %0,%%fr11R" : : "m" (((float*)&l->args[8])[-1])); /* farg8 = ((float*)&l->args[8])[-1]; */
                   else
                     arg8 = l->args[7];
                   if (arglen > 8) {
@@ -205,9 +205,6 @@ avcall_call(av_alist* list)
     /* save return value */
     if (l->rtype == __AVvoid) {
     } else
-    if (l->rtype == __AVword) {
-      RETURN(__avword, iret);
-    } else
     if (l->rtype == __AVchar) {
       RETURN(char, iret);
     } else
@@ -361,36 +358,36 @@ avcall_call(av_alist* list)
             }
           }
           #else /* Optimized: fewer conditional jumps, fewer memory accesses */
-          uintptr_t count = l->rsize; /* > 0, ≤ 2*sizeof(__avword) */
-          __avword* wordaddr = (__avword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avword)-1));
-          uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avword)-1); /* ≥ 0, < sizeof(__avword) */
-          uintptr_t end_offset = start_offset + count; /* > 0, < 3*sizeof(__avword) */
-          if (count <= sizeof(__avword)) {
+          uintptr_t count = l->rsize; /* > 0, ≤ 2*sizeof(__avrword) */
+          __avrword* wordaddr = (__avrword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avrword)-1));
+          uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avrword)-1); /* ≥ 0, < sizeof(__avrword) */
+          uintptr_t end_offset = start_offset + count; /* > 0, < 3*sizeof(__avrword) */
+          if (count <= sizeof(__avrword)) {
             /* Use iret. */
-            if (end_offset <= sizeof(__avword)) {
-              /* 0 < end_offset ≤ sizeof(__avword) */
-              __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - ((__avword)1 << (sizeof(__avword)*8-end_offset*8));
+            if (end_offset <= sizeof(__avrword)) {
+              /* 0 < end_offset ≤ sizeof(__avrword) */
+              __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - ((__avrword)1 << (sizeof(__avrword)*8-end_offset*8));
               wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
             } else {
-              /* sizeof(__avword) < end_offset < 2*sizeof(__avword), start_offset > 0 */
-              __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
-              __avword mask1 = - ((__avword)1 << (2*sizeof(__avword)*8-end_offset*8));
+              /* sizeof(__avrword) < end_offset < 2*sizeof(__avrword), start_offset > 0 */
+              __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
+              __avrword mask1 = - ((__avrword)1 << (2*sizeof(__avrword)*8-end_offset*8));
               wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-              wordaddr[1] ^= (wordaddr[1] ^ (iret << (sizeof(__avword)*8-start_offset*8))) & mask1;
+              wordaddr[1] ^= (wordaddr[1] ^ (iret << (sizeof(__avrword)*8-start_offset*8))) & mask1;
             }
           } else {
             /* Use iret, iret2. */
-            __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
+            __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
             wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-            if (end_offset <= 2*sizeof(__avword)) {
-              /* sizeof(__avword) < end_offset ≤ 2*sizeof(__avword) */
-              __avword mask1 = - ((__avword)1 << (2*sizeof(__avword)*8-end_offset*8));
-              wordaddr[1] ^= (wordaddr[1] ^ ((iret << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret2 >> (start_offset*8)))) & mask1;
+            if (end_offset <= 2*sizeof(__avrword)) {
+              /* sizeof(__avrword) < end_offset ≤ 2*sizeof(__avrword) */
+              __avrword mask1 = - ((__avrword)1 << (2*sizeof(__avrword)*8-end_offset*8));
+              wordaddr[1] ^= (wordaddr[1] ^ ((iret << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret2 >> (start_offset*8)))) & mask1;
             } else {
-              /* 2*sizeof(__avword) < end_offset < 3*sizeof(__avword), start_offset > 0 */
-              __avword mask2 = - ((__avword)1 << (3*sizeof(__avword)*8-end_offset*8));
-              wordaddr[1] = (iret << (sizeof(__avword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
-              wordaddr[2] ^= (wordaddr[2] ^ (iret2 << (sizeof(__avword)*8-start_offset*8))) & mask2;
+              /* 2*sizeof(__avrword) < end_offset < 3*sizeof(__avrword), start_offset > 0 */
+              __avrword mask2 = - ((__avrword)1 << (3*sizeof(__avrword)*8-end_offset*8));
+              wordaddr[1] = (iret << (sizeof(__avrword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
+              wordaddr[2] ^= (wordaddr[2] ^ (iret2 << (sizeof(__avrword)*8-start_offset*8))) & mask2;
             }
           }
           #endif
