@@ -1,6 +1,6 @@
 /**
   Copyright 1993 Bill Triggs <Bill.Triggs@inrialpes.fr>
-  Copyright 1995-2017 Bruno Haible <bruno@clisp.org>
+  Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
   Copyright 2000 Adam Fedor <fedor@gnu.org>
   Copyright 2004 Paul Guyot <pguyot@kallisys.net>
 
@@ -67,8 +67,8 @@ int
 avcall_call(av_alist* list)
 {
   register __avword*	sp	__asm__("r1");  /* C names for registers */
-/*register __avword	iret	__asm__("r3"); */
-  register __avword	iret2	__asm__("r4");
+/*register __avrword	iret	__asm__("r3"); */
+  register __avrword	iret2	__asm__("r4");
   register float	fret	__asm__("fr1");
   register double	dret	__asm__("fr1");
 
@@ -76,7 +76,7 @@ avcall_call(av_alist* list)
 
   __avword* argframe = __builtin_alloca(__AV_ALIST_WORDS * sizeof(__avword)); /* make room for argument list */
   int arglen = l->aptr - l->args;
-  __avword iret;
+  __avrword iret;
   int i;
 
   for (i = 8; i < arglen; i++) /* push function args onto stack */
@@ -130,9 +130,6 @@ avcall_call(av_alist* list)
   /* save return value */
   if (l->rtype == __AVvoid) {
   } else
-  if (l->rtype == __AVword) {
-    RETURN(__avword, iret);
-  } else
   if (l->rtype == __AVchar) {
     RETURN(char, iret);
   } else
@@ -289,36 +286,36 @@ avcall_call(av_alist* list)
           }
         }
         #else /* Optimized: fewer conditional jumps, fewer memory accesses */
-        uintptr_t count = l->rsize; /* > 0, ≤ 2*sizeof(__avword) */
-        __avword* wordaddr = (__avword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avword)-1));
-        uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avword)-1); /* ≥ 0, < sizeof(__avword) */
-        uintptr_t end_offset = start_offset + count; /* > 0, < 3*sizeof(__avword) */
-        if (count <= sizeof(__avword)) {
+        uintptr_t count = l->rsize; /* > 0, ≤ 2*sizeof(__avrword) */
+        __avrword* wordaddr = (__avrword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avrword)-1));
+        uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avrword)-1); /* ≥ 0, < sizeof(__avrword) */
+        uintptr_t end_offset = start_offset + count; /* > 0, < 3*sizeof(__avrword) */
+        if (count <= sizeof(__avrword)) {
           /* Use iret. */
-          if (end_offset <= sizeof(__avword)) {
-            /* 0 < end_offset ≤ sizeof(__avword) */
-            __avword mask0 = ((__avword)2 << (end_offset*8-1)) - ((__avword)1 << (start_offset*8));
+          if (end_offset <= sizeof(__avrword)) {
+            /* 0 < end_offset ≤ sizeof(__avrword) */
+            __avrword mask0 = ((__avrword)2 << (end_offset*8-1)) - ((__avrword)1 << (start_offset*8));
             wordaddr[0] ^= (wordaddr[0] ^ (iret << (start_offset*8))) & mask0;
           } else {
-            /* sizeof(__avword) < end_offset < 2*sizeof(__avword), start_offset > 0 */
-            __avword mask0 = - ((__avword)1 << (start_offset*8));
-            __avword mask1 = ((__avword)2 << (end_offset*8-sizeof(__avword)*8-1)) - 1;
+            /* sizeof(__avrword) < end_offset < 2*sizeof(__avrword), start_offset > 0 */
+            __avrword mask0 = - ((__avrword)1 << (start_offset*8));
+            __avrword mask1 = ((__avrword)2 << (end_offset*8-sizeof(__avrword)*8-1)) - 1;
             wordaddr[0] ^= (wordaddr[0] ^ (iret << (start_offset*8))) & mask0;
-            wordaddr[1] ^= (wordaddr[1] ^ (iret >> (sizeof(__avword)*8-start_offset*8))) & mask1;
+            wordaddr[1] ^= (wordaddr[1] ^ (iret >> (sizeof(__avrword)*8-start_offset*8))) & mask1;
           }
         } else {
           /* Use iret, iret2. */
-          __avword mask0 = - ((__avword)1 << (start_offset*8));
+          __avrword mask0 = - ((__avrword)1 << (start_offset*8));
           wordaddr[0] ^= (wordaddr[0] ^ (iret << (start_offset*8))) & mask0;
-          if (end_offset <= 2*sizeof(__avword)) {
-            /* sizeof(__avword) < end_offset ≤ 2*sizeof(__avword) */
-            __avword mask1 = ((__avword)2 << (end_offset*8-sizeof(__avword)*8-1)) - 1;
-            wordaddr[1] ^= (wordaddr[1] ^ ((iret >> (sizeof(__avword)*4-start_offset*4) >> (sizeof(__avword)*4-start_offset*4)) | (iret2 << (start_offset*8)))) & mask1;
+          if (end_offset <= 2*sizeof(__avrword)) {
+            /* sizeof(__avrword) < end_offset ≤ 2*sizeof(__avrword) */
+            __avrword mask1 = ((__avrword)2 << (end_offset*8-sizeof(__avrword)*8-1)) - 1;
+            wordaddr[1] ^= (wordaddr[1] ^ ((iret >> (sizeof(__avrword)*4-start_offset*4) >> (sizeof(__avrword)*4-start_offset*4)) | (iret2 << (start_offset*8)))) & mask1;
           } else {
-            /* 2*sizeof(__avword) < end_offset < 3*sizeof(__avword), start_offset > 0 */
-            __avword mask2 = ((__avword)2 << (end_offset*8-2*sizeof(__avword)*8-1)) - 1;
-            wordaddr[1] = (iret >> (sizeof(__avword)*8-start_offset*8)) | (iret2 << (start_offset*8));
-            wordaddr[2] ^= (wordaddr[2] ^ (iret2 >> (sizeof(__avword)*8-start_offset*8))) & mask2;
+            /* 2*sizeof(__avrword) < end_offset < 3*sizeof(__avrword), start_offset > 0 */
+            __avrword mask2 = ((__avrword)2 << (end_offset*8-2*sizeof(__avrword)*8-1)) - 1;
+            wordaddr[1] = (iret >> (sizeof(__avrword)*8-start_offset*8)) | (iret2 << (start_offset*8));
+            wordaddr[2] ^= (wordaddr[2] ^ (iret2 >> (sizeof(__avrword)*8-start_offset*8))) & mask2;
           }
         }
         #endif
