@@ -1,6 +1,6 @@
 /**
   Copyright 1993 Bill Triggs <Bill.Triggs@inrialpes.fr>
-  Copyright 1995-2017 Bruno Haible <bruno@clisp.org>
+  Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
   Copyright 2001 Gerhard Tonn <gt@debian.org>
 
   This program is free software: you can redistribute it and/or modify
@@ -48,8 +48,8 @@ int
 avcall_call(av_alist* list)
 {
   register __avword*	sp	__asm__("r15");  /* C names for registers */
-/*register __avword	iret	__asm__("r2"); */
-  register __avword	iret2	__asm__("r3");
+/*register __avrword	iret	__asm__("r2"); */
+  register __avrword	iret2	__asm__("r3");
   register float	fret	__asm__("f0");
   register double	dret	__asm__("f0");
 
@@ -58,7 +58,7 @@ avcall_call(av_alist* list)
   __avword* argframe = __builtin_alloca(__AV_ALIST_WORDS * sizeof(__avword)); /* make room for argument list */
   int arglen = l->aptr - l->args;
   unsigned int fanum = l->fanum;
-  __avword i;
+  __avrword i;
 
   for (i = 0; i < arglen; i++)		/* push function args onto stack */
    argframe[i] = l->args[i];
@@ -80,9 +80,6 @@ avcall_call(av_alist* list)
   /* save return value */
   if (l->rtype == __AVvoid) {
   } else
-  if (l->rtype == __AVword) {
-    RETURN(__avword, i);
-  } else
   if (l->rtype == __AVchar) {
     RETURN(char, i);
   } else
@@ -112,8 +109,8 @@ avcall_call(av_alist* list)
   } else
   if (l->rtype == __AVlonglong || l->rtype == __AVulonglong) {
     void* raddr = l->raddr;
-    ((__avword*)raddr)[0] = i;
-    ((__avword*)raddr)[1] = iret2;
+    ((__avrword*)raddr)[0] = i;
+    ((__avrword*)raddr)[1] = iret2;
   } else
   if (l->rtype == __AVfloat) {
     RETURN(float, fret);
@@ -135,10 +132,10 @@ avcall_call(av_alist* list)
       if (l->rsize == sizeof(int)) {
         RETURN(int, i);
       } else
-      if (l->rsize == 2*sizeof(__avword)) {
+      if (l->rsize == 2*sizeof(__avrword)) {
         void* raddr = l->raddr;
-        ((__avword*)raddr)[0] = i;
-        ((__avword*)raddr)[1] = iret2;
+        ((__avrword*)raddr)[0] = i;
+        ((__avrword*)raddr)[1] = iret2;
       }
     }
   }
