@@ -1,6 +1,6 @@
 /**
   Copyright 1993 Bill Triggs <Bill.Triggs@inrialpes.fr>
-  Copyright 1995-2017 Bruno Haible <bruno@clisp.org>
+  Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -92,12 +92,12 @@
 #define RETURN(TYPE,VAL)	(*(TYPE*)l->raddr = (TYPE)(VAL))
 #define OFFSETOF(struct,member) ((int)&(((struct*)0)->member))
 
-register __avword o0	__asm__("%o0");
-register __avword o1	__asm__("%o1");
-register __avword o2	__asm__("%o2");
-register __avword o3	__asm__("%o3");
-register __avword o4	__asm__("%o4");
-register __avword o5	__asm__("%o5");
+register __avrword o0	__asm__("%o0");
+register __avrword o1	__asm__("%o1");
+register __avrword o2	__asm__("%o2");
+register __avrword o3	__asm__("%o3");
+register __avrword o4	__asm__("%o4");
+register __avrword o5	__asm__("%o5");
 
 int
 avcall_call(av_alist* list)
@@ -110,7 +110,7 @@ avcall_call(av_alist* list)
 
   __avword trampoline[6];		/* room for a trampoline */
   int arglen = l->aptr - l->args;
-  __avword iret;
+  __avrword iret;
 
   if (l->darg_mask) {
     /* push leading float/double args */
@@ -168,7 +168,7 @@ avcall_call(av_alist* list)
   }
 
 					/* call function with 1st 6 args */
-  iret = ({ register __avword iretreg __asm__ ("%o0");
+  iret = ({ register __avrword iretreg __asm__ ("%o0");
             iretreg = (*l->func)(l->args[0], l->args[1], l->args[2],
                                  l->args[3], l->args[4], l->args[5]);
             asm __volatile__("nop");	/* struct returning functions skip this instruction */
@@ -178,9 +178,6 @@ avcall_call(av_alist* list)
   /* save return value */
   if (l->rtype == __AVvoid) {
   } else
-  if (l->rtype == __AVword) {
-    RETURN(__avword, iret);
-  } else
   if (l->rtype == __AVchar) {
     RETURN(char, iret);
   } else
@@ -447,70 +444,70 @@ avcall_call(av_alist* list)
           }
         }
         #else /* Optimized: fewer conditional jumps, fewer memory accesses */
-        uintptr_t count = l->rsize; /* > 0, ≤ 4*sizeof(__avword) */
-        __avword* wordaddr = (__avword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avword)-1));
-        uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avword)-1); /* ≥ 0, < sizeof(__avword) */
-        uintptr_t end_offset = start_offset + count; /* > 0, < 5*sizeof(__avword) */
-        if (count <= sizeof(__avword)) {
+        uintptr_t count = l->rsize; /* > 0, ≤ 4*sizeof(__avrword) */
+        __avrword* wordaddr = (__avrword*)((uintptr_t)raddr & ~(uintptr_t)(sizeof(__avrword)-1));
+        uintptr_t start_offset = (uintptr_t)raddr & (uintptr_t)(sizeof(__avrword)-1); /* ≥ 0, < sizeof(__avrword) */
+        uintptr_t end_offset = start_offset + count; /* > 0, < 5*sizeof(__avrword) */
+        if (count <= sizeof(__avrword)) {
           /* Use iret. */
-          if (end_offset <= sizeof(__avword)) {
-            /* 0 < end_offset ≤ sizeof(__avword) */
-            __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - ((__avword)1 << (sizeof(__avword)*8-end_offset*8));
+          if (end_offset <= sizeof(__avrword)) {
+            /* 0 < end_offset ≤ sizeof(__avrword) */
+            __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - ((__avrword)1 << (sizeof(__avrword)*8-end_offset*8));
             wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
           } else {
-            /* sizeof(__avword) < end_offset < 2*sizeof(__avword), start_offset > 0 */
-            __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
-            __avword mask1 = - ((__avword)1 << (2*sizeof(__avword)*8-end_offset*8));
+            /* sizeof(__avrword) < end_offset < 2*sizeof(__avrword), start_offset > 0 */
+            __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
+            __avrword mask1 = - ((__avrword)1 << (2*sizeof(__avrword)*8-end_offset*8));
             wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-            wordaddr[1] ^= (wordaddr[1] ^ (iret << (sizeof(__avword)*8-start_offset*8))) & mask1;
+            wordaddr[1] ^= (wordaddr[1] ^ (iret << (sizeof(__avrword)*8-start_offset*8))) & mask1;
           }
-        } else if (count <= 2*sizeof(__avword)) {
+        } else if (count <= 2*sizeof(__avrword)) {
           /* Use iret, iret2. */
-          __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
+          __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
           wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-          if (end_offset <= 2*sizeof(__avword)) {
-            /* sizeof(__avword) < end_offset ≤ 2*sizeof(__avword) */
-            __avword mask1 = - ((__avword)1 << (2*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] ^= (wordaddr[1] ^ ((iret << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret2 >> (start_offset*8)))) & mask1;
+          if (end_offset <= 2*sizeof(__avrword)) {
+            /* sizeof(__avrword) < end_offset ≤ 2*sizeof(__avrword) */
+            __avrword mask1 = - ((__avrword)1 << (2*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] ^= (wordaddr[1] ^ ((iret << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret2 >> (start_offset*8)))) & mask1;
           } else {
-            /* 2*sizeof(__avword) < end_offset < 3*sizeof(__avword), start_offset > 0 */
-            __avword mask2 = - ((__avword)1 << (3*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] = (iret << (sizeof(__avword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
-            wordaddr[2] ^= (wordaddr[2] ^ (iret2 << (sizeof(__avword)*8-start_offset*8))) & mask2;
+            /* 2*sizeof(__avrword) < end_offset < 3*sizeof(__avrword), start_offset > 0 */
+            __avrword mask2 = - ((__avrword)1 << (3*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] = (iret << (sizeof(__avrword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
+            wordaddr[2] ^= (wordaddr[2] ^ (iret2 << (sizeof(__avrword)*8-start_offset*8))) & mask2;
           }
-        } else if (count <= 3*sizeof(__avword)) {
+        } else if (count <= 3*sizeof(__avrword)) {
           /* Use iret, iret2, iret3. */
-          __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
+          __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
           wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-          if (end_offset <= 3*sizeof(__avword)) {
-            /* 2*sizeof(__avword) < end_offset ≤ 3*sizeof(__avword) */
-            __avword mask2 = - ((__avword)1 << (3*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] = (iret << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret2 >> (start_offset*8));
-            wordaddr[2] ^= (wordaddr[2] ^ ((iret2 << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret3 >> (start_offset*8)))) & mask2;
+          if (end_offset <= 3*sizeof(__avrword)) {
+            /* 2*sizeof(__avrword) < end_offset ≤ 3*sizeof(__avrword) */
+            __avrword mask2 = - ((__avrword)1 << (3*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] = (iret << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret2 >> (start_offset*8));
+            wordaddr[2] ^= (wordaddr[2] ^ ((iret2 << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret3 >> (start_offset*8)))) & mask2;
           } else {
-            /* 3*sizeof(__avword) < end_offset < 4*sizeof(__avword), start_offset > 0 */
-            __avword mask3 = - ((__avword)1 << (4*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] = (iret << (sizeof(__avword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
-            wordaddr[2] = (iret2 << (sizeof(__avword)*8-start_offset*8)) | (iret3 >> (start_offset*8));
-            wordaddr[3] ^= (wordaddr[3] ^ (iret3 << (sizeof(__avword)*8-start_offset*8))) & mask3;
+            /* 3*sizeof(__avrword) < end_offset < 4*sizeof(__avrword), start_offset > 0 */
+            __avrword mask3 = - ((__avrword)1 << (4*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] = (iret << (sizeof(__avrword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
+            wordaddr[2] = (iret2 << (sizeof(__avrword)*8-start_offset*8)) | (iret3 >> (start_offset*8));
+            wordaddr[3] ^= (wordaddr[3] ^ (iret3 << (sizeof(__avrword)*8-start_offset*8))) & mask3;
           }
         } else {
           /* Use iret, iret2, iret3, iret4. */
-          __avword mask0 = ((__avword)2 << (sizeof(__avword)*8-start_offset*8-1)) - 1;
+          __avrword mask0 = ((__avrword)2 << (sizeof(__avrword)*8-start_offset*8-1)) - 1;
           wordaddr[0] ^= (wordaddr[0] ^ (iret >> (start_offset*8))) & mask0;
-          if (end_offset <= 4*sizeof(__avword)) {
-            /* 3*sizeof(__avword) < end_offset ≤ 4*sizeof(__avword) */
-            __avword mask3 = - ((__avword)1 << (4*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] = (iret << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret2 >> (start_offset*8));
-            wordaddr[2] = (iret2 << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret3 >> (start_offset*8));
-            wordaddr[3] ^= (wordaddr[3] ^ ((iret3 << (sizeof(__avword)*4-start_offset*4) << (sizeof(__avword)*4-start_offset*4)) | (iret4 >> (start_offset*8)))) & mask3;
+          if (end_offset <= 4*sizeof(__avrword)) {
+            /* 3*sizeof(__avrword) < end_offset ≤ 4*sizeof(__avrword) */
+            __avrword mask3 = - ((__avrword)1 << (4*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] = (iret << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret2 >> (start_offset*8));
+            wordaddr[2] = (iret2 << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret3 >> (start_offset*8));
+            wordaddr[3] ^= (wordaddr[3] ^ ((iret3 << (sizeof(__avrword)*4-start_offset*4) << (sizeof(__avrword)*4-start_offset*4)) | (iret4 >> (start_offset*8)))) & mask3;
           } else {
-            /* 4*sizeof(__avword) < end_offset < 5*sizeof(__avword), start_offset > 0 */
-            __avword mask4 = - ((__avword)1 << (5*sizeof(__avword)*8-end_offset*8));
-            wordaddr[1] = (iret << (sizeof(__avword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
-            wordaddr[2] = (iret2 << (sizeof(__avword)*8-start_offset*8)) | (iret3 >> (start_offset*8));
-            wordaddr[3] = (iret3 << (sizeof(__avword)*8-start_offset*8)) | (iret4 >> (start_offset*8));
-            wordaddr[4] ^= (wordaddr[4] ^ (iret4 << (sizeof(__avword)*8-start_offset*8))) & mask4;
+            /* 4*sizeof(__avrword) < end_offset < 5*sizeof(__avrword), start_offset > 0 */
+            __avrword mask4 = - ((__avrword)1 << (5*sizeof(__avrword)*8-end_offset*8));
+            wordaddr[1] = (iret << (sizeof(__avrword)*8-start_offset*8)) | (iret2 >> (start_offset*8));
+            wordaddr[2] = (iret2 << (sizeof(__avrword)*8-start_offset*8)) | (iret3 >> (start_offset*8));
+            wordaddr[3] = (iret3 << (sizeof(__avrword)*8-start_offset*8)) | (iret4 >> (start_offset*8));
+            wordaddr[4] ^= (wordaddr[4] ^ (iret4 << (sizeof(__avrword)*8-start_offset*8))) & mask4;
           }
         }
         #endif
