@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2019 Bruno Haible <bruno@clisp.org>
+ * Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,14 +87,22 @@ template <class type> struct __VA_alignof_helper { char __slot1; type __slot2; }
 extern "C" {
 #endif
 
-/* C builtin types.
+/* __vaword represents a single word that can be pushed on the stack.
+ * __varword represents a general-purpose register.
  */
-#if defined(__mipsn32__) || defined(__x86_64_x32__) || defined(__VA_LLP64)
+#if defined(__arm64__) && defined(__APPLE__) && defined(__MACH__)
+typedef int __vaword;
+typedef long __varword;
+#elif defined(__mipsn32__) || defined(__x86_64_x32__) || defined(__VA_LLP64)
 typedef long long __vaword;
+typedef long long __varword;
 #else
 typedef long __vaword;
+typedef long __varword;
 #endif
 
+/* C builtin types.
+ */
 enum __VAtype
 {
   __VAvoid,
@@ -233,7 +241,7 @@ enum __VA_alist_flags
 #if defined(__powerpc__) && !defined(__powerpc64__) && defined(_AIX) && !defined(__GNUC__) /* AIX 32-bit cc, xlc */
   __VA_STRUCT_ARGS		= __VA_AIXCC_STRUCT_ARGS,
 #else
-#if defined(__powerpc64__) && defined(_AIX) /* AIX 64-bit cc, xlc, gcc */
+#if defined(__powerpc64__) && defined(_AIX) /* AIX 64-bit cc, xlc, gcc, xlclang */
   __VA_STRUCT_ARGS		= __VA_AIXCC_STRUCT_ARGS,
 #else
 #if defined(__ia64__) && !(defined(__GNUC__) && (__GNUC__ >= 3))
@@ -263,7 +271,7 @@ enum __VA_alist_flags
    * before or after #including <vacall_r.h>.
    */
 #ifndef __VA_FLOAT_ARGS
-#if defined(__powerpc64__) && defined(_AIX) && !defined(__GNUC__) /* AIX 64-bit xlc */
+#if defined(__powerpc64__) && defined(_AIX) && (defined(__ibmxl__) || !defined(__GNUC__)) /* AIX 64-bit xlc, xlclang */
   __VA_FLOAT_ARGS		= __VA_AIXCC_FLOAT_ARGS,
 #else
   __VA_FLOAT_ARGS		= 0,
