@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2017 Bruno Haible <bruno@clisp.org>
+ * Copyright 1995-2021 Bruno Haible <bruno@clisp.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef _VACALL_H
@@ -26,7 +26,7 @@
 
 /* Determine whether the current ABI is LLP64
    ('long' = 32-bit, 'long long' = 'void*' = 64-bit). */
-#if defined(__x86_64__) && (defined(_WIN32) || defined(__WIN32__)) && !defined(__CYGWIN__)
+#if defined(__x86_64__) && defined(_WIN32) && !defined(__CYGWIN__)
 #define __VA_LLP64 1
 #endif
 
@@ -48,14 +48,22 @@ template <class type> struct __VA_alignof_helper { char __slot1; type __slot2; }
 extern "C" {
 #endif
 
-/* C builtin types.
+/* __vaword represents a single word that can be pushed on the stack.
+ * __varword represents a general-purpose register.
  */
-#if defined(__mipsn32__) || defined(__x86_64_x32__) || defined(__VA_LLP64)
+#if defined(__arm64__) && defined(__APPLE__) && defined(__MACH__)
+typedef int __vaword;
+typedef long __varword;
+#elif defined(__mipsn32__) || defined(__x86_64_x32__) || defined(__VA_LLP64)
 typedef long long __vaword;
+typedef long long __varword;
 #else
 typedef long __vaword;
+typedef long __varword;
 #endif
 
+/* C builtin types.
+ */
 enum __VAtype
 {
   __VAvoid,
@@ -128,13 +136,13 @@ enum __VA_alist_flags
 #if defined(__sparc__) && !defined(__sparc64__) && defined(__sun) && (defined(__SUNPRO_C) || defined(__SUNPRO_CC)) /* SUNWspro cc or CC */
 				  __VA_SUNPROCC_STRUCT_RETURN,
 #else
-#if (defined(__i386__) && (defined(_WIN32) || defined(__CYGWIN__) || (defined(__MACH__) && defined(__APPLE__)) || defined(__FreeBSD__) || defined(__DragonFly__) || defined(__OpenBSD__))) || defined(__m68k__) || defined(__mipsn32__) || defined(__mips64__) || defined(__sparc64__) || defined(__hppa__) || defined(__hppa64__) || defined(__arm__) || defined(__armhf__) || defined(__arm64__) || defined(__powerpc64_elfv2__) || defined(__ia64__) || defined(__x86_64__)
+#if (defined(__i386__) && (defined(_WIN32) || defined(__CYGWIN__) || (defined(__MACH__) && defined(__APPLE__)) || defined(__FreeBSD__) || defined(__DragonFly__) || defined(__OpenBSD__))) || defined(__m68k__) || defined(__mipsn32__) || defined(__mips64__) || defined(__sparc64__) || defined(__hppa__) || defined(__hppa64__) || defined(__arm__) || defined(__armhf__) || defined(__arm64__) || defined(__powerpc64_elfv2__) || defined(__ia64__) || defined(__x86_64__) || defined(__riscv32__) || defined(__riscv64__)
 				  __VA_SMALL_STRUCT_RETURN |
 #endif
 #if defined(__GNUC__) && !((defined(__mipsn32__) || defined(__mips64__)) && ((__GNUC__ == 3 && __GNUC_MINOR__ >= 4) || (__GNUC__ > 3)))
 				  __VA_GCC_STRUCT_RETURN |
 #endif
-#if defined(__i386__) && (defined(_WIN32) || defined(__WIN32__)) && !defined(__CYGWIN__) /* native Windows */
+#if defined(__i386__) && defined(_WIN32) && !defined(__CYGWIN__) /* native Windows */
 				  __VA_MSVC_STRUCT_RETURN |
 #endif
 				  0,
@@ -194,7 +202,7 @@ enum __VA_alist_flags
 #if defined(__powerpc__) && !defined(__powerpc64__) && defined(_AIX) && !defined(__GNUC__) /* AIX 32-bit cc, xlc */
   __VA_STRUCT_ARGS		= __VA_AIXCC_STRUCT_ARGS,
 #else
-#if defined(__powerpc64__) && defined(_AIX) /* AIX 64-bit cc, xlc, gcc */
+#if defined(__powerpc64__) && defined(_AIX) /* AIX 64-bit cc, xlc, gcc, xlclang */
   __VA_STRUCT_ARGS		= __VA_AIXCC_STRUCT_ARGS,
 #else
 #if defined(__ia64__) && !(defined(__GNUC__) && (__GNUC__ >= 3))
@@ -224,7 +232,7 @@ enum __VA_alist_flags
    * before or after #including <vacall.h>.
    */
 #ifndef __VA_FLOAT_ARGS
-#if defined(__powerpc64__) && defined(_AIX) && !defined(__GNUC__) /* AIX 64-bit xlc */
+#if defined(__powerpc64__) && defined(_AIX) && (defined(__ibmxl__) || !defined(__GNUC__)) /* AIX 64-bit xlc, xlclang */
   __VA_FLOAT_ARGS		= __VA_AIXCC_FLOAT_ARGS,
 #else
   __VA_FLOAT_ARGS		= 0,
@@ -245,7 +253,7 @@ enum __VA_alist_flags
 #endif
 
   /* These are for internal use only */
-#if defined(__i386__) || defined(__m68k__) || defined(__mipsn32__) || defined(__mips64__) || defined(__sparc64__) || defined(__alpha__) || defined(__hppa64__) || defined(__arm__) || defined(__armhf__) || defined(__arm64__) || defined(__powerpc__) || defined(__powerpc64__) || defined(__ia64__) || defined(__x86_64__) || (defined(__s390__) && !defined(__s390x__))
+#if defined(__i386__) || defined(__m68k__) || defined(__mipsn32__) || defined(__mips64__) || defined(__sparc64__) || defined(__alpha__) || defined(__hppa64__) || defined(__arm__) || defined(__armhf__) || defined(__arm64__) || defined(__powerpc__) || defined(__powerpc64__) || defined(__ia64__) || defined(__x86_64__) || (defined(__s390__) && !defined(__s390x__)) || defined(__riscv64__)
   __VA_REGISTER_STRUCT_RETURN	= 1<<10,
 #endif
 #if defined(__mipsn32__) || defined(__mips64__)
